@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "el-patch" "3.1.1"
+(define-package "el-patch" "20250816.21"
   "Future-proof your Elisp."
   '((emacs "26"))
   :url "https://github.com/radian-software/el-patch"
